==> haskell-crypton-x509-validation-1.6.12-28-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-x509-validation
version:              1.6.12
visibility:           public
id:                   crypton-x509-validation-1.6.12-J2THso0m0AY3tVMIMMznSF
key:                  crypton-x509-validation-1.6.12-J2THso0m0AY3tVMIMMznSF
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  4ad08a36c73610d967da7ebfe191be64
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/crypton-x509-validation-1.6.12

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/crypton-x509-validation-1.6.12

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-validation
hs-libraries:         HScrypton-x509-validation-1.6.12-J2THso0m0AY3tVMIMMznSF
depends:
    asn1-encoding-0.9.6-IkosapRt3AP5MNPOrKN0lm
    asn1-types-0.3.4-Hyn5kZFolX7gxDa6hTx8x base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    crypton-0.34-GAkeRvOUCMVBanETWHsxsb
    crypton-x509-1.7.6-HFBcqeAbhtn89434QYBXF2
    crypton-x509-store-1.6.9-Afv5K7p2zU3KBs8x57IGfl
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp
    hourglass-0.2.12-IgEtyVcSREg9suG8D80qmq
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1 mtl-2.2.2
    pem-0.2.4-5N4eCpXQrJA1x0C3DKrXBd

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-validation/html/crypton-x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-validation/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-validation-1.6.12-30-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-x509-validation
version:              1.6.12
visibility:           public
id:                   crypton-x509-validation-1.6.12-7ZyExDpUmnZ1cUBcLaAtHd
key:                  crypton-x509-validation-1.6.12-7ZyExDpUmnZ1cUBcLaAtHd
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  1709b5918cfa6e73ec63c36e2ac4a441
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/crypton-x509-validation-1.6.12

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/crypton-x509-validation-1.6.12

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-validation
hs-libraries:         HScrypton-x509-validation-1.6.12-7ZyExDpUmnZ1cUBcLaAtHd
depends:
    asn1-encoding-0.9.6-6GqwFFmrDK82IsCOUk2PEt
    asn1-types-0.3.4-Jw71wui5Ob54LqM1Y0htWU base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    crypton-0.34-67uX59Sjjsw2dJbbUWUzWH
    crypton-x509-1.7.6-AT1aSHFzIIlFru8iIljDNg
    crypton-x509-store-1.6.9-1ZCh3S9RSOYGP90oOcCrLh
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp
    hourglass-0.2.12-AqgCZcM6ZmxAi8T3YvbuVc
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1 mtl-2.2.2
    pem-0.2.4-DcNj6eIVIfzGJuAlSYXCHc

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-validation/html/crypton-x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-validation/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
